OCIS Document Index

# OSCN navigation

| Index of Available Documents |

Up One Level | Show Levels |

# Oklahoma Court of Criminal Appeals Cases
(STOKCSCR)
1908 to Present (entire history)
Search

Decisions published in 2014

2014 OK CR 1, 01/28/2014, STATE v. MARCUM

2014 OK CR 2, 03/27/2014, SOTO v. STATE

2014 OK CR 3, 04/18/2014, LOCKETT v. STATE

2014 OK CR 4, 04/28/2014, STATE v. FARTHING

2014 OK CR 5, 05/20/2014, ARGANBRIGHT v. STATE

2014 OK CR 6, 06/19/2014, IN RE REVISION OF PORTION OF RULES OF COURT OF CRIMINAL APPEALS

2014 OK CR 7, 06/23/2014, IN RE REVISION OF PORTION OF RULES OF COURT OF CRIMINAL APPEALS